@@ -6,7 +6,8 @@ import urllib2
 import logging
 from urllib import urlencode
 
-POSTBACK_URL = 'https://www.payfast.co.za/eng/query/validate'
+POSTBACK_URL = '/eng/query/validate'
+POSTBACK_SERVER = 'https://www.payfast.co.za'
 
 def _values_to_encode(data):
     return [
@@ -26,13 +27,13 @@ def siganture(data):
     text = _signature_string(data)
     return md5(text).hexdigest()
 
-def data_is_valid(post_data, postback_url=POSTBACK_URL):
+def data_is_valid(post_data, postback_server=POSTBACK_SERVER):
     """
     Validates data via the postback. Returns True if data is valid,
     False if data is invalid and None if the request failed.
     """
     post_str = urlencode(_values_to_encode(post_data))
-    logging.info(post_str)
+    postback_url = postback_server.rstrip('/') + POSTBACK_URL
     try:
         response = urllib2.urlopen(postback_url, post_str).read()
     except urllib2.HTTPError:
